summaryrefslogtreecommitdiff
path: root/test-cli/test/tests/qwifi.py
diff options
context:
space:
mode:
Diffstat (limited to 'test-cli/test/tests/qwifi.py')
-rw-r--r--test-cli/test/tests/qwifi.py19
1 files changed, 10 insertions, 9 deletions
diff --git a/test-cli/test/tests/qwifi.py b/test-cli/test/tests/qwifi.py
index 2a5fa0c..8daf069 100644
--- a/test-cli/test/tests/qwifi.py
+++ b/test-cli/test/tests/qwifi.py
@@ -4,14 +4,14 @@ import re
class Qwifi(unittest.TestCase):
- __sip = None
+ __serverip = None
__numbytestx = None
__bind = None
- __OKBW = None
+ __bwexpected = None
__port = None
params = None
#varlist: serverip, bind, OKBW, port
def __init__(self, testname, testfunc, varlist):
self.params = varlist
super(Qwifi, self).__init__(testfunc)
@@ -19,8 +19,8 @@ class Qwifi(unittest.TestCase):
self.__serverip = varlist["serverip"]
else:
raise Exception('serverip param inside Qwifi have been be defined')
- if "OKBW" in varlist:
- self.__OKBW = varlist["OKBW"]
+ if "bwexpected" in varlist:
+ self.__bwexpected = varlist["bwexpected"]
else:
raise Exception('OKBW param inside Qwifi must be defined')
if "port" in varlist:
@@ -41,11 +41,12 @@ class Qwifi(unittest.TestCase):
# get the first line of the output stream
out1 = p.stdout.decode('ascii').splitlines()[0]
if out1 != "Not connected.":
- #check if the board has ip in the wlan0 interface
+ # check if the board has ip in the wlan0 interface
p = sh.ifconfig("wlan0")
if p.exit_code == 0:
- result = re.search("inet addr:(?!127\.0{1,3}\.0{1,3}\.0{0,2}1$)((25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)",
- p.stdout)
+ result = re.search(
+ 'inet addr:(?!127\.0{1,3}\.0{1,3}\.0{0,2}1$)((25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)',
+ p.stdout.decode('ascii'))
if result:
# execute iperf command against the server
if self.__bind is None:
@@ -69,7 +70,7 @@ class Qwifi(unittest.TestCase):
bwreal = b[0]
# check if BW is in the expected range
- self.failUnless(float(bwreal) > float(self.__OKBW) * 0.9,
+ self.failUnless(float(bwreal) > float(self.__bwexpected) * 0.9,
"failed: speed is lower than spected. Speed(MB/s)" + str(bwreal))
else:
self.fail("failed: could not complete iperf command")
@@ -4,14 +4,14 @@ import re
__port = None
params = None
- #varlist: serverip, bind, OKBW, port
+ # varlist content: serverip, bwexpected, port, (optional)bind
def __init__(self, testname, testfunc, varlist):
self.params = varlist